@@ -20,16 +20,19 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor,
 # Boston, MA  02110-1301  USA
 
+import os
+
 import gi
+gi.require_version('Gedit', '3.0')
+gi.require_version('Gtk', '3.0')
 gi.require_version('Vte', '2.91')
 from gi.repository import GObject, GLib, Gio, Pango, Gdk, Gtk, Gedit, Vte
-import os
-import gettext
-from gpdefs import *
 
 try:
-    gettext.bindtextdomain(GETTEXT_PACKAGE, GP_LOCALEDIR)
-    _ = lambda s: gettext.dgettext(GETTEXT_PACKAGE, s);
+    import gettext
+    gettext.bindtextdomain('gedit-plugins')
+    gettext.textdomain('gedit-plugins')
+    _ = gettext.gettext
 except:
     _ = lambda s: s
 
@@ -65,7 +68,7 @@ class GeditTerminal(Vte.Terminal):
 
     def do_drag_data_received(self, drag_context, x, y, data, info, time):
         if info == self.TARGET_URI_LIST:
-            self.feed_child(' '.join(["'" + Gio.file_new_for_uri(item).get_path() + "'" for item in Gedit.utils_drop_get_uris(data)]), -1)
+            self.feed_child(' '.join(["'" + Gio.file_new_for_uri(item).get_path() + "'" for item in Gedit.utils_drop_get_uris(data)]).encode('utf-8'))
             Gtk.drag_finish(drag_context, True, False, time);
         else:
             Vte.Terminal.do_drag_data_received(self, drag_context, x, y, data, info, time)
@@ -273,12 +276,12 @@ class GeditTerminalPanel(Gtk.Box):
         menu.attach_to_widget(self, None)
 
         if event is not None:
-            menu.popup(None, None, None, None, event.button, event.time)
+            menu.popup_at_pointer(event)
         else:
-            menu.popup(None, None,
-                       lambda m: Gedit.utils_menu_position_under_widget(m, self),
-                       None,
-                       0, Gtk.get_current_event_time())
+            menu.popup_at_widget(self,
+                                 Gdk.Gravity.NORTH_WEST,
+                                 Gdk.Gravity.SOUTH_WEST,
+                                 None)
             menu.select_first(False)
 
     def copy_clipboard(self):
@@ -291,7 +294,7 @@ class GeditTerminalPanel(Gtk.Box):
 
     def change_directory(self, path):
         path = path.replace('\\', '\\\\').replace('"', '\\"')
-        self._vte.feed_child('cd "%s"\n' % path, -1)
+        self._vte.feed_child(('cd "%s"\n' % path).encode('utf-8'))
         self._vte.grab_focus()
 
 class TerminalPlugin(GObject.Object, Gedit.WindowActivatable):
